@@ -63,19 +63,25 @@ toGroup x = Group x [] []
 ---------------------------------------------------------------------
 -- TYPES
 
--- | A mode. Each mode has three main features:
+-- | A mode. Do not use the 'Mode' constructor directly, instead
+--   use 'mode' to construct the 'Mode' and then record updates.
+--   Each mode has three main features:
 --
 --   * A list of submodes ('modeGroupModes')
 --
 --   * A list of flags ('modeGroupFlags')
 --
 --   * Optionally an unnamed argument ('modeArgs')
+--
+--  To produce the help information for a mode, either use 'helpText' or 'show'.
 data Mode a = Mode
     {modeGroupModes :: Group (Mode a) -- ^ The available sub-modes
     ,modeNames :: [Name] -- ^ The names assigned to this mode (for the root mode, this name is used as the program name)
     ,modeValue :: a -- ^ Value to start with
     ,modeCheck :: a -> Either String a -- ^ Check the value reprsented by a mode is correct, after applying all flags
     ,modeReform :: a -> Maybe [String] -- ^ Given a value, try to generate the input arguments.
+    ,modeExpandAt :: Bool -- ^ Expand @\@@ arguments with 'expandArgsAt', defaults to 'True', only applied if using an 'IO' processing function.
+                          --   Only the root 'Mode's value will be used.
     ,modeHelp :: Help -- ^ Help text
     ,modeHelpSuffix :: [String] -- ^ A longer help suffix displayed after a mode
     ,modeArgs :: ([Arg a], Maybe (Arg a)) -- ^ The unnamed arguments, a series of arguments, followed optionally by one for all remaining slots
@@ -204,7 +210,7 @@ remapUpdate f g upd = \s v -> let (a,b) = g v in fmap b $ upd s a
 -- | Create an empty mode specifying only 'modeValue'. All other fields will usually be populated
 --   using record updates.
 modeEmpty :: a -> Mode a
-modeEmpty x = Mode mempty [] x Right (const Nothing) "" [] ([],Nothing) mempty
+modeEmpty x = Mode mempty [] x Right (const Nothing) True "" [] ([],Nothing) mempty
 
 -- | Create a mode with a name, an initial value, some help text, a way of processing arguments
 --   and a list of flags.
